@@ -1,13 +1,13 @@
 ## File Name: ma.wtd.sdNA.R
-## File Version: 0.07
+## File Version: 0.08
 
 
-###############################################################################
-# weighted SD
+
+#--- weighted SD
 ma.wtd.sdNA <- function( data, weights=NULL, vars=NULL, method="unbiased" )
 {
     #*** pre-processing
-    res <- ma.wtd.aux.data(data=data, weights=weights, vars=vars )
+    res <- ma_wtd_stat_prepare_data(data=data, weights=weights, vars=vars )
     data <- res$data
     weights <- res$weights
     M <- length(data)
@@ -39,6 +39,3 @@ ma.wtd.sdNA <- function( data, weights=NULL, vars=NULL, method="unbiased" )
     names(res) <- colnames(data[[1]])
     return( res )
 }
-###############################################################################
-
-
