@@ -1,5 +1,5 @@
 ## File Name: micombine.chisquare.R
-## File Version: 0.21
+## File Version: 0.22
 
 
 micombine.chisquare <- function( dk, df, display=TRUE, version=1)
@@ -12,14 +12,14 @@ micombine.chisquare <- function( dk, df, display=TRUE, version=1)
         df2 <- ( M - 1 )/ df^(3/M)  * ( 1  + M / ( M + 1/M) / sdk.square )^2
     }
     if (version==1){
-            g2 <- dk
-            m <- length(g2);
-            g <- sqrt(g2);
-            mg2 <- sum(g2)/m;
-            r <- (1+1/m)*(sum(g^2)-(sum(g)^2)/m)/(m-1);
-            Dval <- (mg2/df - r*(m+1)/(m-1))/(1+r);
-            df2 <-  (m-1)*(1+1/r)**2/df^(3/m);
-        }
+        g2 <- dk
+        m <- length(g2)
+        g <- sqrt(g2)
+        mg2 <- sum(g2)/m
+        r <- (1+1/m)*(sum(g^2)-(sum(g)^2)/m)/(m-1)
+        Dval <- (mg2/df - r*(m+1)/(m-1))/(1+r)
+        df2 <-  (m-1)*(1+1/r)**2/df^(3/m)
+    }
     pval <- stats::pf( Dval, df1=df, df2=df2, lower.tail=FALSE)
 
     #--- chi square approximation
